﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using VeteransAffairs.Registries.Business;
using VeteransAffairs.Registries.BusinessManager;
using VeteransAffairs.Registries.BusinessManager.TBI;
using VeteransAffairs.Registries.BusinessManager.Utilities;
using System.Runtime.InteropServices;
using Telerik.Web.UI;

public partial class InstrumentEvaluationEntry : BaseTBIInstrumentPage
{
    #region Variable Declarations

    PatientManager pManager = new PatientManager();
    int surveyTypeId = 2;
    SURVEY evalSurvey;

    #endregion

    #region Public Methods

    public InstrumentEvaluationEntry()
    {
        //Manager Save Notification Event Handler
        pManager.BOSaveSuccess += manager_BOSaveSuccess;
    }

    #endregion

    #region Protected Methods

    protected void Page_Load(object sender, EventArgs e)
    {
        try
        {
            //TBIServiceTO _tbiServiceTo;
            //_tbiServiceTo = (TBIServiceTO)Session["TBIServiceTO"];
            //_tbiInstrumentManager.TbiServiceTo = _tbiServiceTo;
            _tbiInstrumentManager.TbiServiceTo = base.GetTBIServiceTo();

            if (!IsPostBack)
            {
                //turn off viewstate for all radiobuttonlists
                this.GetAllControls().OfType<RadioButtonList>().ToList().ForEach(c => c.EnableViewState = false);
                
                //These are DataBound controls and need viewstate
                rblMedicationReconciliationPerformed.EnableViewState = true;
                rblMedicationGiven.EnableViewState = true;

                rblMedicationReconciliationPerformed.Attributes["onclick"] = "rblMedicationReconciliationPerformed_CheckChanged()";
                ScriptManager.RegisterStartupScript(this, this.GetType(), "rblMedicationReconciliationPerformed_CheckChanged", "rblMedicationReconciliationPerformed_CheckChanged()", true);

                //Load DataBound controls
                List<STD_QUESTION_CHOICE> list = new List<STD_QUESTION_CHOICE>();
                list = _tbiInstrumentManager.GetChoicesByQuestionNumberandSurveyType("21-A", "COMP TBI EVAL");
                list.RemoveAt(0);
                rblMedicationReconciliationPerformed.DataSource = list;
                rblMedicationReconciliationPerformed.DataBind();

                list = _tbiInstrumentManager.GetChoicesByQuestionNumberandSurveyType("21-B", "COMP TBI EVAL");
                list.RemoveAt(0);
                rblMedicationGiven.DataSource = list;
                rblMedicationGiven.DataBind();

                string ssn = string.Empty;

                if (_tbiInstrumentManager.TbiServiceTo == null)
                {
                    //TODO post error
                }
                else
                {
                    base.AddtoViewStateTBIServiceTo(_tbiInstrumentManager.TbiServiceTo);

                    ssn = _tbiInstrumentManager.TbiServiceTo.PatientSSN;

                    LabelPatient.Text = _tbiInstrumentManager.TbiServiceTo.PatientName;
                    LabelSSN.Text = _tbiInstrumentManager.TbiServiceTo.PatientSSN.Trim().Length == 9 ? String.Format("{0:000-00-0000}", int.Parse(_tbiInstrumentManager.TbiServiceTo.PatientSSN)) : _tbiInstrumentManager.TbiServiceTo.PatientSSN;

                    Label labelUser = (Label)Master.FindControl("LabelCurrentUser");
                    if (labelUser != null)
                    {
                        labelUser.Text = _tbiInstrumentManager.TbiServiceTo.UserName;
                    }
                }

                if (!string.IsNullOrEmpty(ssn))
                {
                    string patICN = pManager.GetPatientICNBySSN(ssn);

                    if (!string.IsNullOrEmpty(patICN))
                    {
                        ViewState["PatientICN"] = patICN;
                        getRefreshEvalSurvey(patICN);

                    }
                    else
                    {
                        throw new ArgumentException("Patient with this SSN does not exist.");
                    }

                    string referrer = "";
                    if (Request.UrlReferrer != null)
                    {
                        referrer = Request.UrlReferrer.PathAndQuery;
                    }
                    ViewState["referrer"] = referrer;

                    if (evalSurvey != null)
                    {
                        if (evalSurvey.isNew)
                        {
                            SetDefaultValues();
                        }
                        else
                        {
                            SetUpEvalSurvey(evalSurvey);
                        }
                    }
                }


                InjuryYearRangeValidator.MinimumValue = "2001";
                InjuryYearRangeValidator.MaximumValue = DateTime.Today.Year.ToString();

                SecondInjuryYearRangeValidator.MinimumValue = "2001";
                SecondInjuryYearRangeValidator.MaximumValue = DateTime.Today.Year.ToString();

                LeastInjuryYearRangeValidator.MinimumValue = "2001";
                LeastInjuryYearRangeValidator.MaximumValue = DateTime.Today.Year.ToString();

                bool enabledState = true;
                if (evalSurvey != null)
                {
                    if (!String.IsNullOrEmpty(evalSurvey.SURVEY_STATUS))
                    {
                        if (evalSurvey.SURVEY_STATUS.ToLower() == "completed")
                            enabledState = false;
                    }
                }
                SaveButton.Enabled = SavePrepareNoteButton.Enabled = enabledState;
            }
        }
        catch (Exception ex2)
        {
            Exception _tbilogerror = HandleTBIException(ex2, "InstrumentEvaluationEntry.aspx", "100029", "Page_Load()");
        }
    }

    protected override void LoadViewState(object savedState)
    {
        base.LoadViewState(savedState);
        string surveyXml = (string)ViewState["surveyXml"];
        evalSurvey = SerializerUtil.Deserialize<SURVEY>(surveyXml);
    }

    protected override object SaveViewState()
    {
        ViewState["surveyXml"] = evalSurvey.Serialize();
        return base.SaveViewState();
    }

    protected void SaveSurvey_Click(object sender, EventArgs e)
    {
        Int32 status = 0;

        SaveFailMessage = "";

        SaveCompleteSurvey(ref status);

        SetUpEvalSurvey(evalSurvey);
    }

    /// <summary>
    /// Cancel button clicked.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void CancelSurvey_Click(object sender, EventArgs e)
    {
        ViewState["surveyXml"] = null;
        ViewState["PatientICN"] = null;
        ViewState["referrer"] = null;
        Session.Remove("survey");
        Response.Redirect("Instrument.aspx", false);
        //this.ClientScript.RegisterStartupScript(typeof(Page), "closePage", "<script type='text/javascript'> window.open('','_self','');window.close(); </script>");
    }

    protected void SavePrepareNote_Click(object sender, EventArgs e)
    {
        try
        {
            Int32 status = 0;

            SaveFailMessage = "Save Failed. Please press " + SavePrepareNoteButton.Text + " button again to avoid data loss.";

            SaveCompleteSurvey(ref status);

            if (status > 0)
            {
                Session["survey"] = evalSurvey;
                Response.Redirect("InstrumentSummaryNote.aspx", false);
            }
            else
            {
                SetUpEvalSurvey(evalSurvey); //Follow Save Draft logic 
            }
        }
        catch (Exception ex)
        {
            Exception _tbilogerror = HandleTBIException(ex, "InstrumentEvaluationEntry.aspx", "100029", "SavePrepareNote_Click()");
        }
    }

    /// <summary>
    /// Inactive timer firing.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void InActiveTimer_Tick(object sender, EventArgs e)
    {
        Int32 status = 0;
        SaveFailMessage = "Save Failed. Please press " + SaveButton.Text + " button again to avoid data loss.";

        //Page.Validate();

        //if (Page.IsValid)
        //{
            SaveCompleteSurvey(ref status);
            //SetUpSurvey(_survey);
            Response.Redirect("InstrumentEvaluationEntry.aspx", false);
        //}
        //else
        //{
        //    SaveFailMessage = "Auto-Save Validation Failed. Please complete required fields in the survey and press " + SaveButton.Text + " button again to avoid data loss.";
        //}
    }

    #endregion

    #region Private Methods

    private void getRefreshEvalSurvey(string patientICN)
    {
        //var surveys = _tbiInstrumentManager.SelectByPatientIdAndSurveyType(patientId, surveyTypeId, false).ToList();
        try
        {
            var surveys = _tbiInstrumentManager.SelectByPatientICNAndSurveyType(patientICN, surveyTypeId, false).ToList();

            if (surveys.Count > 0)
            {
                evalSurvey = surveys.First();

            }
            else
            {
                evalSurvey = new SURVEY();

            }

            evalSurvey.SetAsChangeTrackingRoot();
        }
        catch (Exception ex)
        {
            Exception _tbilogerror = HandleTBIException(ex, "InstrumentEvaluationEntry.aspx", "100029", "getRefreshEvalSurvey()");
        }

    }

    private void SaveCompleteSurvey(ref Int32 status)
    {
        string patientICN = String.Empty;

        status = 0;

        try
        {
            //Retrieve patient's ICN from the session variable
            if (ViewState["PatientICN"] != null)
            {
                patientICN = ViewState["PatientICN"].ToString();
                if (String.IsNullOrEmpty(patientICN.Trim()))
                {
                    //Lost state. Redirect to message that need to log back in from CPRS.
                    Response.Redirect("Warning.aspx?err=2", false);
                }
            }
            else
            {
                //Lost state. Redirect to message that need to log back in from CPRS.
                Response.Redirect("Warning.aspx?err=2", false);
            }

            if (evalSurvey.isNew)
            {
                //Ensure that a concurrent session hasn't already inserted a record for this survey
                var surveys = _tbiInstrumentManager.SelectByPatientICNAndSurveyType(patientICN, surveyTypeId, true).ToList();

                if (surveys.Count > 0)
                {
                    //A concurrent session has already inserted a record for this survey and it is not new anymore.
                    Response.Redirect("Warning.aspx?err=9", false);
                }
                else
                {
                    evalSurvey.SURVEY_STATUS = "inprocess";

                    evalSurvey.SetAsInsertOnSubmit();

                    evalSurvey.patient_ICN = patientICN;

                    evalSurvey.STD_SURVEY_TYPE_ID = surveyTypeId;
                    evalSurvey.SURVEY_DATE = DateTime.Today;

                    //Save survey if it's new before adding any responses
                    _tbiInstrumentManager.Update(evalSurvey);

                    getRefreshEvalSurvey(patientICN);
                }
            }

            SaveSurvey(ref evalSurvey);

            evalSurvey.SetAsUpdateOnSubmit();
            status = _tbiInstrumentManager.Update(evalSurvey);

            (this.Master as RegistryInstrumentMaster).SetDirtyFlag(false);

            getRefreshEvalSurvey(patientICN);
            SuppressSaveMessage = false;
        }
        catch (Exception ex)
        {
            Exception _tbilogerror = HandleTBIException(ex, "InstrumentEvaluationEntry.aspx", "100029", "SaveCompleteSurvey()");
        }
    }

    private void SaveSurvey(ref SURVEY survey)
    {
        try
        {
            SURVEY_RESULT result;
            List<STD_QUESTION> questions = GetAllQuestionsForEvalSurvey();

            //Delete all the survey results from database if there are any.
            SURVEY surveyWithResults = _tbiInstrumentManager.GetSurveyWithAllAnswers(survey.SURVEYS_ID);
            _tbiInstrumentManager.DeleteAllSurveyResults(surveyWithResults);

            if (rbnonVAProvider.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "A");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("A", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbnonVAProvider.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbnonVAProvider.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }
            }

            if (rbMaritalStatus.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "1");

                //var count = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE != null && c.STD_QUESTION_CHOICE.STD_QUESTION != null && c.STD_QUESTION_CHOICE.STD_QUESTION.QUESTION_NUMBER == "1").Count();
                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("1", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbMaritalStatus.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;
                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbMaritalStatus.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }
            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "1");

                //var count = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE != null && c.STD_QUESTION_CHOICE.STD_QUESTION != null && c.STD_QUESTION_CHOICE.STD_QUESTION.QUESTION_NUMBER == "1").Count();
                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("1", survey.SURVEYS_ID);

                if (rbnonVAProvider.SelectedValue == "1")
                {
                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);
                    }
                }
                else
                {
                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.SetAsDeleteOnSubmit();
                    }
                }
            }

            if (rbEducationalLevel.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "2");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("2", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbEducationalLevel.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;
                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbEducationalLevel.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "2");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("2", survey.SURVEYS_ID);

                if (rbnonVAProvider.SelectedValue == "1")
                {
                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);
                    }
                }
                else
                {
                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.SetAsDeleteOnSubmit();
                    }
                }
            }

            if (rbEmploymentStatus.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "3");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("3", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbEmploymentStatus.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbEmploymentStatus.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }
            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "3");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("3", survey.SURVEYS_ID);

                if (rbnonVAProvider.SelectedValue == "1")
                {
                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);
                    }
                }
                else
                {
                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.SetAsDeleteOnSubmit();
                    }
                }
            }

            if (rbInjuriesQuantity.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "4");
                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("4", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbInjuriesQuantity.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;
                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbInjuriesQuantity.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }
            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "4");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("4", survey.SURVEYS_ID);

                if (rbnonVAProvider.SelectedValue == "1")
                {


                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }
                }
                else
                {
                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.SetAsDeleteOnSubmit();

                    }
                }
            }

            STD_QUESTION fourA1question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "4-A-1");

            List<SURVEY_RESULT> fourA1results = _tbiInstrumentManager.GetChoicesByQuestionNumber("4-A-1", survey.SURVEYS_ID);

            if (rbnonVAProvider.SelectedValue == "1" || rbInjuriesQuantity.SelectedValue == "0")
            {

                if (fourA1results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == fourA1results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                    result.STD_QUESTION_CHOICE_ID = fourA1question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                    result.RESULT_TEXT = InjuryMonthTextBox.Text.Trim();

                }
                else
                {
                    result = new SURVEY_RESULT();
                    result.STD_QUESTION_CHOICE_ID = fourA1question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                if (fourA1results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == fourA1results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = fourA1question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == 1).STD_QUESTION_CHOICE_ID;
                    result.RESULT_TEXT = InjuryMonthTextBox.Text.Trim();

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = fourA1question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == 1).STD_QUESTION_CHOICE_ID;
                    result.RESULT_TEXT = InjuryMonthTextBox.Text.Trim();

                    survey.SURVEY_RESULTs.Add(result);
                }
            }

            STD_QUESTION fourA2question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "4-A-2");

            List<SURVEY_RESULT> fourA2results = _tbiInstrumentManager.GetChoicesByQuestionNumber("4-A-2", survey.SURVEYS_ID);

            if (rbnonVAProvider.SelectedValue == "1" || rbInjuriesQuantity.SelectedValue == "0")
            {

                if (fourA2results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == fourA2results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                    result.STD_QUESTION_CHOICE_ID = fourA2question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                    result.RESULT_TEXT = InjuryYearTextBox.Text.Trim();

                }
                else
                {
                    result = new SURVEY_RESULT();
                    result.STD_QUESTION_CHOICE_ID = fourA2question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                if (fourA2results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == fourA2results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = fourA2question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == 1).STD_QUESTION_CHOICE_ID;
                    result.RESULT_TEXT = InjuryYearTextBox.Text.Trim();
                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = fourA2question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == 1).STD_QUESTION_CHOICE_ID;
                    result.RESULT_TEXT = InjuryYearTextBox.Text.Trim();

                    survey.SURVEY_RESULTs.Add(result);
                }
            }

            STD_QUESTION fourB1question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "4-B-1");

            List<SURVEY_RESULT> fourB1results = _tbiInstrumentManager.GetChoicesByQuestionNumber("4-B-1", survey.SURVEYS_ID);

            if (rbnonVAProvider.SelectedValue == "1" || rbInjuriesQuantity.SelectedValue == "0" || rbInjuriesQuantity.SelectedValue == "1")
            {

                if (fourB1results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == fourB1results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                    result.STD_QUESTION_CHOICE_ID = fourB1question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                    result.RESULT_TEXT = SecondInjuryMonthTextBox.Text.Trim();

                }
                else
                {
                    result = new SURVEY_RESULT();
                    result.STD_QUESTION_CHOICE_ID = fourB1question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                if (fourB1results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == fourB1results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = fourB1question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == 1).STD_QUESTION_CHOICE_ID;
                    result.RESULT_TEXT = SecondInjuryMonthTextBox.Text.Trim();

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = fourB1question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == 1).STD_QUESTION_CHOICE_ID;
                    result.RESULT_TEXT = SecondInjuryMonthTextBox.Text.Trim();

                    survey.SURVEY_RESULTs.Add(result);
                }
            }

            STD_QUESTION fourB2question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "4-B-2");

            List<SURVEY_RESULT> fourB2results = _tbiInstrumentManager.GetChoicesByQuestionNumber("4-B-2", survey.SURVEYS_ID);

            if (rbnonVAProvider.SelectedValue == "1" || rbInjuriesQuantity.SelectedValue == "0" || rbInjuriesQuantity.SelectedValue == "1")
            {

                if (fourB2results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == fourB2results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                    result.STD_QUESTION_CHOICE_ID = fourB2question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                    result.RESULT_TEXT = null;

                }
                else
                {
                    result = new SURVEY_RESULT();
                    result.STD_QUESTION_CHOICE_ID = fourB2question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                if (fourB2results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == fourB2results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = fourB2question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == 1).STD_QUESTION_CHOICE_ID;
                    result.RESULT_TEXT = SecondInjuryYearTextBox.Text.Trim();

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = fourB2question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == 1).STD_QUESTION_CHOICE_ID;
                    result.RESULT_TEXT = SecondInjuryYearTextBox.Text.Trim();

                    survey.SURVEY_RESULTs.Add(result);
                }
            }

            STD_QUESTION fourC1question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "4-C-1");

            List<SURVEY_RESULT> fourC1results = _tbiInstrumentManager.GetChoicesByQuestionNumber("4-C-1", survey.SURVEYS_ID);

            if (rbnonVAProvider.SelectedValue == "1" || rbInjuriesQuantity.SelectedValue == "0" || rbInjuriesQuantity.SelectedValue == "1"
                || rbInjuriesQuantity.SelectedValue == "2")
            {

                if (fourC1results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == fourC1results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                    result.STD_QUESTION_CHOICE_ID = fourC1question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                    result.RESULT_TEXT = null;

                }
                else
                {
                    result = new SURVEY_RESULT();
                    result.STD_QUESTION_CHOICE_ID = fourC1question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                if (fourC1results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == fourC1results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = fourC1question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == 1).STD_QUESTION_CHOICE_ID;
                    result.RESULT_TEXT = LeastInjuryMonthTextBox.Text.Trim();

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = fourC1question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == 1).STD_QUESTION_CHOICE_ID;
                    result.RESULT_TEXT = LeastInjuryMonthTextBox.Text.Trim();

                    survey.SURVEY_RESULTs.Add(result);
                }
            }


            STD_QUESTION fourC2question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "4-C-2");

            List<SURVEY_RESULT> fourC2results = _tbiInstrumentManager.GetChoicesByQuestionNumber("4-C-2", survey.SURVEYS_ID);

            if (rbnonVAProvider.SelectedValue == "1" || rbInjuriesQuantity.SelectedValue == "0" || rbInjuriesQuantity.SelectedValue == "1"
                || rbInjuriesQuantity.SelectedValue == "2")
            {

                if (fourC2results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == fourC2results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                    result.STD_QUESTION_CHOICE_ID = fourC2question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                    result.RESULT_TEXT = null;

                }
                else
                {
                    result = new SURVEY_RESULT();
                    result.STD_QUESTION_CHOICE_ID = fourC2question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                if (fourC2results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == fourC2results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = fourC2question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == 1).STD_QUESTION_CHOICE_ID;
                    result.RESULT_TEXT = LeastInjuryYearTextBox.Text.Trim();

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = fourC2question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == 1).STD_QUESTION_CHOICE_ID;
                    result.RESULT_TEXT = LeastInjuryYearTextBox.Text.Trim();

                    survey.SURVEY_RESULTs.Add(result);
                }
            }


            if (rbFiveASubsection.SelectedIndex > -1)
            {

                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "5-A");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("5-A", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbFiveASubsection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {

                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbFiveASubsection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);

                }

            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "5-A");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("5-A", survey.SURVEYS_ID);

                if (rbnonVAProvider.SelectedValue == "1" || rbInjuriesQuantity.SelectedValue == "0")
                {


                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }

                }
                else
                {
                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.SetAsDeleteOnSubmit();

                    }
                }
            }

            if (rbFiveBSubsection.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "5-B");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("5-B", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbFiveBSubsection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {

                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbFiveBSubsection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);

                }

            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "5-B");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("5-B", survey.SURVEYS_ID);

                if (rbnonVAProvider.SelectedValue == "1" || rbInjuriesQuantity.SelectedValue == "0")
                {


                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }

                }
                else
                {
                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.SetAsDeleteOnSubmit();

                    }
                }

            }

            if (rbFiveCSubsection.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "5-C");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("5-C", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbFiveCSubsection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {

                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbFiveCSubsection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);

                }
            }
            else
            {

                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "5-C");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("5-C", survey.SURVEYS_ID);

                if (rbnonVAProvider.SelectedValue == "1" || rbInjuriesQuantity.SelectedValue == "0")
                {


                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }

                }
                else
                {
                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.SetAsDeleteOnSubmit();

                    }
                }
            }

            if (rbFiveDSubsection.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "5-D");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("5-D", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbFiveDSubsection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {

                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbFiveDSubsection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);

                }
            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "5-D");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("5-D", survey.SURVEYS_ID);

                if (rbnonVAProvider.SelectedValue == "1" || rbInjuriesQuantity.SelectedValue == "0")
                {


                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }

                }
                else
                {
                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.SetAsDeleteOnSubmit();

                    }
                }

            }

            if (rbFiveDOneSubsection.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "5-D-1");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("5-D-1", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbFiveDOneSubsection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {

                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbFiveDOneSubsection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);

                }
            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "5-D-1");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("5-D-1", survey.SURVEYS_ID);

                if (rbnonVAProvider.SelectedValue == "1" || rbInjuriesQuantity.SelectedValue == "0" || rbFiveDSubsection.SelectedValue == "0")
                {

                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }

                }
                else
                {
                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.SetAsDeleteOnSubmit();

                    }
                }
            }

            if (rbFiveDOneASection.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "5-D-1-a");
                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("5-D-1-a", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbFiveDOneASection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {

                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbFiveDOneASection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);

                }
            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "5-D-1-a");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("5-D-1-a", survey.SURVEYS_ID);

                if (rbnonVAProvider.SelectedValue == "1" || rbInjuriesQuantity.SelectedValue == "0" || rbFiveDSubsection.SelectedValue == "0")
                {


                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }

                }
                else
                {
                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.SetAsDeleteOnSubmit();

                    }
                }
            }

            if (rbFiveDTwoSection.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "5-D-2");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("5-D-2", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbFiveDTwoSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {

                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbFiveDTwoSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);

                }
            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "5-D-2");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("5-D-2", survey.SURVEYS_ID);

                if (rbnonVAProvider.SelectedValue == "1" || rbFiveDSubsection.SelectedValue == "0" || rbInjuriesQuantity.SelectedValue == "0")
                {


                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }

                }
                else
                {
                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.SetAsDeleteOnSubmit();

                    }
                }

            }

            if (rbFiveDThreeSection.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "5-D-3");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("5-D-3", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbFiveDThreeSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {

                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbFiveDThreeSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);

                }
            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "5-D-3");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("5-D-3", survey.SURVEYS_ID);

                if (rbnonVAProvider.SelectedValue == "1" || rbInjuriesQuantity.SelectedValue == "0" || rbFiveDSubsection.SelectedValue == "0")
                {

                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }

                }
                else
                {
                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.SetAsDeleteOnSubmit();

                    }
                }
            }

            if (rbFiveDFourSection.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "5-D-4");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("5-D-4", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbFiveDFourSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {

                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbFiveDFourSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);

                }
            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "5-D-4");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("5-D-4", survey.SURVEYS_ID);

                if (rbnonVAProvider.SelectedValue == "1" || rbInjuriesQuantity.SelectedValue == "0" || rbFiveDSubsection.SelectedValue == "0")
                {


                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }
                }
                else
                {
                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.SetAsDeleteOnSubmit();

                    }
                }

            }

            //now save type of blast explosure which is multi-select

            int selectedItems = 0;

            STD_QUESTION questionBlastExposure = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "5-D-5");
            List<SURVEY_RESULT> resultsBlastExposure = _tbiInstrumentManager.GetChoicesByQuestionNumber("5-D-5", survey.SURVEYS_ID);

            foreach (ListItem item in BlastExplosureTypeList.Items)
            {
                //result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE != null && c.STD_QUESTION_CHOICE.STD_QUESTION != null && c.STD_QUESTION_CHOICE.STD_QUESTION.QUESTION_NUMBER == "5-D-5" && c.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER == int.Parse(item.Value)).FirstOrDefault();
                //result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.).FirstOrDefault();                              

                var selection = resultsBlastExposure.Where(c => c.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER == int.Parse(item.Value)).FirstOrDefault();


                if (item.Selected)
                {
                    selectedItems++;
                    if (selection != null)
                    {
                        //found it so it was here and no need to add it


                    }
                    else
                    {
                        //have not found it so need to add it.
                        result = new SURVEY_RESULT();

                        result.STD_QUESTION_CHOICE_ID = questionBlastExposure.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == int.Parse(item.Value)).STD_QUESTION_CHOICE_ID;

                        survey.SURVEY_RESULTs.Add(result);
                    }
                }
                else
                {
                    if (selection != null)
                    {
                        //found it so need to remove it 
                        result = survey.SURVEY_RESULTs.FirstOrDefault(c => c.STD_QUESTION_CHOICE_ID == selection.STD_QUESTION_CHOICE_ID);
                        //result.SetAsDeleteOnSubmit();
                        result.SetAsDeleteOnSubmit();
                    }
                    else
                    {
                        //it wasn't there so no need to do anything
                    }
                }
            }

            if (selectedItems == 0)
            {
                if (rbnonVAProvider.SelectedValue == "1" || rbInjuriesQuantity.SelectedValue == "0" || rbFiveDSubsection.SelectedValue == "0")
                {
                    STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "5-D-5");

                    SURVEY_RESULT res = resultsBlastExposure.Where(c => c.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER == null).FirstOrDefault();

                    if (res == null)
                    {
                        result = new SURVEY_RESULT();

                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                        survey.SURVEY_RESULTs.Add(result);
                    }
                }
            }
            else
            {
                SURVEY_RESULT res = resultsBlastExposure.Where(c => c.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER == null).FirstOrDefault();

                if (res != null)
                {
                    result = survey.SURVEY_RESULTs.FirstOrDefault(c => c.STD_QUESTION_CHOICE_ID == res.STD_QUESTION_CHOICE_ID);

                    result.SetAsDeleteOnSubmit();

                }
            }



            if (rbFiveESection.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "5-E");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("5-E", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbFiveESection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {

                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbFiveESection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);

                }
            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "5-E");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("5-E", survey.SURVEYS_ID);

                if (rbnonVAProvider.SelectedValue == "1" || rbInjuriesQuantity.SelectedValue == "0" || rbFiveDSubsection.SelectedValue == "0")
                {


                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }

                }
                else
                {
                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.SetAsDeleteOnSubmit();

                    }
                }
            }

            if (rbSixSection.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "6");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("6", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSixSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSixSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }
            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "6");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("6", survey.SURVEYS_ID);

                if (rbnonVAProvider.SelectedValue == "1" || rbInjuriesQuantity.SelectedValue == "0")
                {


                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }

                }
                else
                {
                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.SetAsDeleteOnSubmit();

                    }
                }
            }

            if (rbSixASection.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "6-A");
                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("6-A", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSixASection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSixASection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "6-A");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("6-A", survey.SURVEYS_ID);

                if (rbnonVAProvider.SelectedValue == "1" || rbInjuriesQuantity.SelectedValue == "0" || rbSixSection.SelectedValue == "0" || rbSixSection.SelectedValue == "6")
                {


                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }

                }
                else
                {
                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.SetAsDeleteOnSubmit();

                    }
                }

            }

            if (rbSevenSection.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "7");
                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("7", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSevenSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSevenSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "7");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("7", survey.SURVEYS_ID);

                if (rbnonVAProvider.SelectedValue == "1" || rbInjuriesQuantity.SelectedValue == "0")
                {


                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }

                }
                else
                {
                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.SetAsDeleteOnSubmit();

                    }
                }

            }

            if (rbSevenASection.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "7-A");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("7-A", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSevenASection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSevenASection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "7-A");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("7-A", survey.SURVEYS_ID);

                if (rbnonVAProvider.SelectedValue == "1" || rbInjuriesQuantity.SelectedValue == "0" || rbSevenSection.SelectedValue == "0" || rbSevenSection.SelectedValue == "6")
                {

                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);
                    }
                }
                else
                {
                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.SetAsDeleteOnSubmit();

                    }
                }

            }

            if (rbEightSection.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "8");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("8", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbEightSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbEightSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "8");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("8", survey.SURVEYS_ID);

                if (rbnonVAProvider.SelectedValue == "1" || rbInjuriesQuantity.SelectedValue == "0")
                {


                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }
                }
                else
                {
                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.SetAsDeleteOnSubmit();

                    }
                }
            }


            if (rbEightASection.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "8-A");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("8-A", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbEightASection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbEightASection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "8-A");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("8-A", survey.SURVEYS_ID);

                if (rbnonVAProvider.SelectedValue == "1"
                    || rbInjuriesQuantity.SelectedValue == "0" || rbEightSection.SelectedValue == "0" || rbEightSection.SelectedValue == "6")
                {


                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }

                }
                else
                {
                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.SetAsDeleteOnSubmit();

                    }
                }
            }

            if (rbNineSection.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "9");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("9", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbNineSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbNineSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "9");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("9", survey.SURVEYS_ID);

                if (rbnonVAProvider.SelectedValue == "1" || rbInjuriesQuantity.SelectedValue == "0")
                {

                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }

                }
                else
                {
                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.SetAsDeleteOnSubmit();

                    }
                }

            }

            if (rbTenSection.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "10");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("10", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbTenSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbTenSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "10");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("10", survey.SURVEYS_ID);

                if (rbnonVAProvider.SelectedValue == "1" || rbInjuriesQuantity.SelectedValue == "0")
                {


                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }
                }
                else
                {
                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.SetAsDeleteOnSubmit();

                    }
                }

            }

            if (rbElevenSection.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "11");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("11", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbElevenSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbElevenSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "11");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("11", survey.SURVEYS_ID);

                if (rbnonVAProvider.SelectedValue == "1" || rbInjuriesQuantity.SelectedValue == "0")
                {


                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }

                }
                else
                {
                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.SetAsDeleteOnSubmit();

                    }
                }
            }

            if (rbTwelveSection.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "12");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("12", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbTwelveSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbTwelveSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "12");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("12", survey.SURVEYS_ID);

                if (rbnonVAProvider.SelectedValue == "1" || rbInjuriesQuantity.SelectedValue == "0")
                {


                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }
                }
                else
                {
                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.SetAsDeleteOnSubmit();

                    }
                }
            }

            if (rbTwelveASection.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "12-A");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("12-A", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbTwelveASection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbTwelveASection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {

                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "12-A");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("12-A", survey.SURVEYS_ID);
                if (rbnonVAProvider.SelectedValue == "1" || rbInjuriesQuantity.SelectedValue == "0" || rbTwelveSection.SelectedValue == "0")
                {


                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }
                }
                else
                {
                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.SetAsDeleteOnSubmit();

                    }
                }
            }

            if (rbThirteenSection.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "13");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("13", survey.SURVEYS_ID);


                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbThirteenSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbThirteenSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "13");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("13", survey.SURVEYS_ID);

                if (rbnonVAProvider.SelectedValue == "1" || rbInjuriesQuantity.SelectedValue == "0")
                {


                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }

                }
                else
                {
                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.SetAsDeleteOnSubmit();

                    }
                }

            }

            if (rbFourteenSection.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "14");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("14", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbFourteenSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbFourteenSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {

                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "14");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("14", survey.SURVEYS_ID);

                if (rbnonVAProvider.SelectedValue == "1")
                {


                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }
                }
                else
                {
                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.SetAsDeleteOnSubmit();

                    }
                }
            }

            if (rbFifteenSection.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "15");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("15", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbFifteenSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbFifteenSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "15");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("15", survey.SURVEYS_ID);

                if (rbnonVAProvider.SelectedValue == "1")
                {


                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }
                }
                else
                {
                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.SetAsDeleteOnSubmit();

                    }
                }

            }

            if (rbSixteenASection.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "16-A");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("16-A", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSixteenASection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSixteenASection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "16-A");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("16-A", survey.SURVEYS_ID);

                if (rbnonVAProvider.SelectedValue == "1")
                {

                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }
                }
                else
                {
                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.SetAsDeleteOnSubmit();

                    }
                }

            }

            if (rbSixteenBSection.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "16-B");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("16-B", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSixteenBSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSixteenBSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "16-B");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("16-B", survey.SURVEYS_ID);

                if (rbnonVAProvider.SelectedValue == "1" || rbSixSection.SelectedValue == "0")
                {


                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }
                }
                else
                {
                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.SetAsDeleteOnSubmit();

                    }
                }

            }

            if (rbSixteenCSection.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "16-C");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("16-C", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSixteenCSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSixteenCSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "16-C");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("16-C", survey.SURVEYS_ID);

                if (rbnonVAProvider.SelectedValue == "1")
                {

                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }
                }
                else
                {
                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.SetAsDeleteOnSubmit();

                    }
                }

            }

            if (rbSixteenDSection.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "16-D");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("16-D", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSixteenDSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSixteenDSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "16-D");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("16-D", survey.SURVEYS_ID);

                if (rbnonVAProvider.SelectedValue == "1")
                {


                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }

                }
                else
                {
                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.SetAsDeleteOnSubmit();

                    }
                }

            }

            if (rbSixteenESection.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "16-E");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("16-E", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSixteenESection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSixteenESection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "16-E");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("16-E", survey.SURVEYS_ID);

                if (rbnonVAProvider.SelectedValue == "1")
                {

                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }
                }
                else
                {
                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.SetAsDeleteOnSubmit();

                    }
                }

            }

            if (rbSixteenFSection.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "16-F");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("16-F", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSixteenFSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSixteenFSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "16-F");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("16-F", survey.SURVEYS_ID);

                if (rbnonVAProvider.SelectedValue == "1")
                {

                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }
                }
                else
                {
                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.SetAsDeleteOnSubmit();

                    }
                }
            }

            if (rbSixteenGSection.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "16-G");
                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("16-G", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSixteenGSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSixteenGSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "16-G");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("16-G", survey.SURVEYS_ID);

                if (rbnonVAProvider.SelectedValue == "1")
                {


                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }
                }
                else
                {
                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.SetAsDeleteOnSubmit();

                    }
                }
            }

            if (rbSixteenHSection.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "16-H");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("16-H", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();


                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSixteenHSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSixteenHSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "16-H");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("16-H", survey.SURVEYS_ID);

                if (rbnonVAProvider.SelectedValue == "1")
                {

                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }
                }
                else
                {
                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.SetAsDeleteOnSubmit();

                    }
                }

            }

            if (rbSixteenISection.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "16-I");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("16-I", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSixteenISection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSixteenISection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "16-I");
                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("16-I", survey.SURVEYS_ID);
                if (rbnonVAProvider.SelectedValue == "1")
                {


                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }

                }
                else
                {
                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.SetAsDeleteOnSubmit();

                    }
                }


            }

            if (rbSixteenJSection.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "16-J");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("16-J", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSixteenJSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSixteenJSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "16-J");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("16-J", survey.SURVEYS_ID);

                if (rbnonVAProvider.SelectedValue == "1")
                {


                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }
                }
                else
                {
                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.SetAsDeleteOnSubmit();

                    }
                }
            }

            if (rbSixteenKSection.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "16-K");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("16-K", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSixteenKSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSixteenKSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }
            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "16-K");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("16-K", survey.SURVEYS_ID);

                if (rbnonVAProvider.SelectedValue == "1")
                {

                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }
                }
                else
                {
                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.SetAsDeleteOnSubmit();

                    }
                }

            }

            if (rbSixteenLSection.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "16-L");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("16-L", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSixteenLSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSixteenLSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "16-L");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("16-L", survey.SURVEYS_ID);

                if (rbnonVAProvider.SelectedValue == "1")
                {

                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }
                }
                else
                {
                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.SetAsDeleteOnSubmit();

                    }
                }
            }

            if (rbSixteenMSection.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "16-M");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("16-M", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSixteenMSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSixteenMSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "16-M");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("16-M", survey.SURVEYS_ID);
                if (rbnonVAProvider.SelectedValue == "1")
                {

                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }
                }
                else
                {
                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.SetAsDeleteOnSubmit();

                    }
                }

            }

            if (rbSixteenNSection.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "16-N");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("16-N", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSixteenNSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSixteenNSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "16-N");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("16-N", survey.SURVEYS_ID);

                if (rbnonVAProvider.SelectedValue == "1")
                {

                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }
                }
                else
                {
                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.SetAsDeleteOnSubmit();

                    }
                }
            }

            if (rbSixteenOSection.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "16-O");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("16-O", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSixteenOSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSixteenOSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "16-O");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("16-O", survey.SURVEYS_ID);

                if (rbnonVAProvider.SelectedValue == "1")
                {


                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }
                }
                else
                {
                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.SetAsDeleteOnSubmit();

                    }
                }
            }

            if (rbSixteenPSection.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "16-P");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("16-P", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSixteenPSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSixteenPSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "16-P");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("16-P", survey.SURVEYS_ID);

                if (rbnonVAProvider.SelectedValue == "1")
                {

                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }
                }
                else
                {
                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.SetAsDeleteOnSubmit();

                    }
                }

            }

            if (rbSixteenQSection.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "16-Q");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("16-Q", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSixteenQSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSixteenQSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "16-Q");
                if (rbnonVAProvider.SelectedValue == "1")
                {
                    List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("16-Q", survey.SURVEYS_ID);

                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }
                }

            }

            if (rbSixteenRSection.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "16-R");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("16-R", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSixteenRSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSixteenRSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "16-R");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("16-R", survey.SURVEYS_ID);

                if (rbnonVAProvider.SelectedValue == "1")
                {

                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }
                }
                else
                {
                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.SetAsDeleteOnSubmit();

                    }
                }
            }

            if (rbSixteenSSection.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "16-S");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("16-S", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSixteenSSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSixteenSSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "16-S");
                if (rbnonVAProvider.SelectedValue == "1")
                {
                    List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("16-S", survey.SURVEYS_ID);

                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }
                }
            }

            if (rbSixteenTSection.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "16-T");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("16-T", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSixteenTSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSixteenTSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "16-T");
                if (rbnonVAProvider.SelectedValue == "1")
                {
                    List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("16-T", survey.SURVEYS_ID);

                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }
                }
            }

            if (rbSixteenUSection.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "16-U");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("16-U", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSixteenUSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSixteenUSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "16-U");
                if (rbnonVAProvider.SelectedValue == "1")
                {
                    List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("16-U", survey.SURVEYS_ID);

                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }
                }
            }

            if (rbSixteenVSection.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "16-V");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("16-V", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSixteenVSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSixteenVSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "16-V");
                if (rbnonVAProvider.SelectedValue == "1")
                {
                    List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("16-V", survey.SURVEYS_ID);

                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }
                }

            }

            if (rbSeventeenSection.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "17");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("17", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSeventeenSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSeventeenSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "17");
                if (rbnonVAProvider.SelectedValue == "1")
                {
                    List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("17", survey.SURVEYS_ID);

                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }
                }
            }

            if (!String.IsNullOrEmpty(LifeAreasDifficultiesTextBox.Text.Trim()))
            {

                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "17-A");
                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("17-A", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == 1).STD_QUESTION_CHOICE_ID;
                    result.RESULT_TEXT = LifeAreasDifficultiesTextBox.Text.Trim();

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == 1).STD_QUESTION_CHOICE_ID;
                    result.RESULT_TEXT = LifeAreasDifficultiesTextBox.Text.Trim();

                    survey.SURVEY_RESULTs.Add(result);

                }

            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "17-A");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("17-A", survey.SURVEYS_ID);

                if (rbnonVAProvider.SelectedValue == "1" || rbSeventeenSection.SelectedValue == "0")
                {

                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        result.RESULT_TEXT = null;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);
                    }

                }
                else
                {                    //textbox was emptied manually so just delete result
                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.SetAsDeleteOnSubmit();

                    }
                }
            }

            if (rbEighteenSection.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "18");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("18", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbEighteenSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbEighteenSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "18");
                if (rbnonVAProvider.SelectedValue == "1")
                {
                    List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("18", survey.SURVEYS_ID);

                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }
                }
            }

            //18-A multi-select question
            STD_QUESTION questionPainLocation = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "18-A");
            List<SURVEY_RESULT> resultsPainLocation = _tbiInstrumentManager.GetChoicesByQuestionNumber("18-A", survey.SURVEYS_ID);

            selectedItems = 0;
            foreach (ListItem item in BodyPartsList.Items)
            {
                //result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE != null && c.STD_QUESTION_CHOICE.STD_QUESTION != null && c.STD_QUESTION_CHOICE.STD_QUESTION.QUESTION_NUMBER == "5-D-5" && c.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER == int.Parse(item.Value)).FirstOrDefault();
                //result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.).FirstOrDefault();                              

                var selection = resultsPainLocation.Where(c => c.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER == int.Parse(item.Value)).FirstOrDefault();


                if (item.Selected)
                {
                    selectedItems++;
                    if (selection != null)
                    {
                        //found it so it was here and no need to add it


                    }
                    else
                    {
                        //have not found it so need to add it.
                        result = new SURVEY_RESULT();

                        result.STD_QUESTION_CHOICE_ID = questionPainLocation.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == int.Parse(item.Value)).STD_QUESTION_CHOICE_ID;

                        survey.SURVEY_RESULTs.Add(result);
                    }
                }
                else
                {
                    if (selection != null)
                    {
                        //found it so need to remove it 
                        result = survey.SURVEY_RESULTs.FirstOrDefault(c => c.STD_QUESTION_CHOICE_ID == selection.STD_QUESTION_CHOICE_ID);
                        //result.SetAsDeleteOnSubmit();
                        result.SetAsDeleteOnSubmit();
                    }
                    else
                    {
                        //it wasn't there so no need to do anything

                    }
                }
            }
            //}
            if (selectedItems == 0)
            {
                if (rbEighteenSection.SelectedValue == "0" || rbnonVAProvider.SelectedValue == "1")
                {
                    STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "18-A");

                    SURVEY_RESULT res = resultsPainLocation.Where(c => c.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER == null).FirstOrDefault();

                    if (res == null)
                    {
                        result = new SURVEY_RESULT();

                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                        survey.SURVEY_RESULTs.Add(result);
                    }
                }
            }
            else
            {
                SURVEY_RESULT res = resultsPainLocation.Where(c => c.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER == null).FirstOrDefault();

                if (res != null)
                {
                    result = survey.SURVEY_RESULTs.FirstOrDefault(c => c.STD_QUESTION_CHOICE_ID == res.STD_QUESTION_CHOICE_ID);

                    result.SetAsDeleteOnSubmit();

                }
            }

            if (rbEighteenBSection.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "18-B");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("18-B", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbEighteenBSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbEighteenBSection.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "18-B");
                if (rbnonVAProvider.SelectedValue == "1" || rbEighteenSection.SelectedValue == "0")
                {
                    List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("18-B", survey.SURVEYS_ID);

                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }
                }

            }

            if (!String.IsNullOrEmpty(LifeAreasPainTextBox.Text.Trim()))
            {

                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "18-C");
                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("18-C", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == 1).STD_QUESTION_CHOICE_ID;
                    result.RESULT_TEXT = LifeAreasPainTextBox.Text.Trim();

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == 1).STD_QUESTION_CHOICE_ID;
                    result.RESULT_TEXT = LifeAreasPainTextBox.Text.Trim();

                    survey.SURVEY_RESULTs.Add(result);

                }

            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "18-C");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("18-C", survey.SURVEYS_ID);

                if (rbnonVAProvider.SelectedValue == "1" || rbEighteenSection.SelectedValue == "0"
                    || rbEighteenBSection.SelectedValue == "0")
                {

                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        result.RESULT_TEXT = null;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);
                    }

                }
                else
                {                    //textbox was emptied manually so just delete result
                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.SetAsDeleteOnSubmit();

                    }
                }

            }

            if (rbSectionNineteen.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "19");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("19", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSectionNineteen.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSectionNineteen.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "19");
                if (rbnonVAProvider.SelectedValue == "1")
                {
                    List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("19", survey.SURVEYS_ID);

                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }
                }
            }

            STD_QUESTION question20 = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "20");

            List<SURVEY_RESULT> results20 = _tbiInstrumentManager.GetChoicesByQuestionNumber("20", survey.SURVEYS_ID);

            if (rbnonVAProvider.SelectedValue == "1")
            {

                if (results20.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results20.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                    result.STD_QUESTION_CHOICE_ID = question20.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                    result.RESULT_TEXT = null;

                }
                else
                {
                    result = new SURVEY_RESULT();
                    result.STD_QUESTION_CHOICE_ID = question20.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                if (results20.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results20.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question20.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == 1).STD_QUESTION_CHOICE_ID;
                    result.RESULT_TEXT = AdditionalHistoryTextBox.Text.Trim();

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question20.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == 1).STD_QUESTION_CHOICE_ID;
                    result.RESULT_TEXT = AdditionalHistoryTextBox.Text.Trim();

                    survey.SURVEY_RESULTs.Add(result);
                }
            }


            STD_QUESTION question21 = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "21");

            List<SURVEY_RESULT> results21 = _tbiInstrumentManager.GetChoicesByQuestionNumber("21", survey.SURVEYS_ID);

            if (rbnonVAProvider.SelectedValue == "1")
            {

                if (results21.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results21.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                    result.STD_QUESTION_CHOICE_ID = question21.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                    result.RESULT_TEXT = null;

                }
                else
                {
                    result = new SURVEY_RESULT();
                    result.STD_QUESTION_CHOICE_ID = question21.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {

                if (results21.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results21.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question21.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == 1).STD_QUESTION_CHOICE_ID;
                    result.RESULT_TEXT = CurrentMedicationTextBox.Text.Trim();

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question21.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == 1).STD_QUESTION_CHOICE_ID;
                    result.RESULT_TEXT = CurrentMedicationTextBox.Text.Trim();

                    survey.SURVEY_RESULTs.Add(result);
                }
            }

            if (rblMedicationReconciliationPerformed.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "21-A");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("21-A", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rblMedicationReconciliationPerformed.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rblMedicationReconciliationPerformed.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }
            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "21-A");
                if (rbnonVAProvider.SelectedValue == "1" || rblMedicationReconciliationPerformed.SelectedValue == "0")
                {
                    List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("21-A", survey.SURVEYS_ID);

                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }
                }
            }

            if (rblMedicationReconciliationPerformed.SelectedItem != null && rblMedicationReconciliationPerformed.SelectedItem.Text.Contains("Yes") && rblMedicationGiven.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "21-B");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("21-B", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rblMedicationGiven.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rblMedicationGiven.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }
            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "21-B");
                if (rbnonVAProvider.SelectedValue == "1" || rblMedicationGiven.SelectedValue == "0")
                {
                    List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("21-B", survey.SURVEYS_ID);

                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }
                }
            }

            if (rblMedicationReconciliationPerformed.SelectedItem != null && rblMedicationReconciliationPerformed.SelectedItem.Text.Contains("No"))
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "21-C");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("21-C", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == 1).STD_QUESTION_CHOICE_ID;
                    result.RESULT_TEXT = txtNoMedicationReconciliationPerformed.Text.Trim();

                }
                else
                {
                    result = new SURVEY_RESULT();
                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == 1).STD_QUESTION_CHOICE_ID;
                    survey.SURVEY_RESULTs.Add(result);
                    result.RESULT_TEXT = txtNoMedicationReconciliationPerformed.Text.Trim();
                }
            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "21-C");
                if (rbnonVAProvider.SelectedValue == "1" || rblMedicationReconciliationPerformed.SelectedValue == "0")
                {
                    List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("21-C", survey.SURVEYS_ID);

                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        result.RESULT_TEXT = null;
                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);
                    }
                }
            }

            STD_QUESTION question22 = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "22");

            List<SURVEY_RESULT> results22 = _tbiInstrumentManager.GetChoicesByQuestionNumber("22", survey.SURVEYS_ID);

            if (rbnonVAProvider.SelectedValue == "1")
            {

                if (results22.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results22.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                    result.STD_QUESTION_CHOICE_ID = question22.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                    result.RESULT_TEXT = null;

                }
                else
                {
                    result = new SURVEY_RESULT();
                    result.STD_QUESTION_CHOICE_ID = question22.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                if (results22.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results22.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question22.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == 1).STD_QUESTION_CHOICE_ID;
                    result.RESULT_TEXT = PhysicalExaminationTextBox.Text.Trim();

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question22.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == 1).STD_QUESTION_CHOICE_ID;
                    result.RESULT_TEXT = PhysicalExaminationTextBox.Text.Trim();

                    survey.SURVEY_RESULTs.Add(result);
                }
            }


            if (rbSectionTwentyThree.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "23");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("23", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSectionTwentyThree.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSectionTwentyThree.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "23");
                if (rbnonVAProvider.SelectedValue == "1")
                {
                    List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("23", survey.SURVEYS_ID);

                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }
                }
            }


            STD_QUESTION questionSymptoms = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "23-A");
            List<SURVEY_RESULT> resultsSymptoms = _tbiInstrumentManager.GetChoicesByQuestionNumber("23-A", survey.SURVEYS_ID);

            selectedItems = 0;
            foreach (ListItem item in DisorderSymptomsList.Items)
            {
                //result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE != null && c.STD_QUESTION_CHOICE.STD_QUESTION != null && c.STD_QUESTION_CHOICE.STD_QUESTION.QUESTION_NUMBER == "5-D-5" && c.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER == int.Parse(item.Value)).FirstOrDefault();
                //result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.).FirstOrDefault();                              

                var selection = resultsSymptoms.Where(c => c.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER == int.Parse(item.Value)).FirstOrDefault();


                if (item.Selected)
                {
                    selectedItems++;
                    if (selection != null)
                    {
                        //found it so it was here and no need to add it


                    }
                    else
                    {
                        //have not found it so need to add it.
                        result = new SURVEY_RESULT();

                        result.STD_QUESTION_CHOICE_ID = questionSymptoms.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == int.Parse(item.Value)).STD_QUESTION_CHOICE_ID;

                        survey.SURVEY_RESULTs.Add(result);
                    }
                }
                else
                {
                    if (selection != null)
                    {
                        //found it so need to remove it 
                        result = survey.SURVEY_RESULTs.FirstOrDefault(c => c.STD_QUESTION_CHOICE_ID == selection.STD_QUESTION_CHOICE_ID);
                        //result.SetAsDeleteOnSubmit();
                        result.SetAsDeleteOnSubmit();
                    }
                    else
                    {
                        //it wasn't there so no need to do anything

                    }
                }
            }
            //}
            if (selectedItems == 0)
            {
                if (rbSectionTwentyThree.SelectedValue == "0" || rbnonVAProvider.SelectedValue == "1")
                {
                    STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "23-A");

                    SURVEY_RESULT res = resultsSymptoms.Where(c => c.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER == null).FirstOrDefault();

                    if (res == null)
                    {
                        result = new SURVEY_RESULT();

                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                        survey.SURVEY_RESULTs.Add(result);
                    }
                }
            }
            else
            {
                SURVEY_RESULT res = resultsSymptoms.Where(c => c.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER == null).FirstOrDefault();

                if (res != null)
                {
                    result = survey.SURVEY_RESULTs.FirstOrDefault(c => c.STD_QUESTION_CHOICE_ID == res.STD_QUESTION_CHOICE_ID);

                    result.SetAsDeleteOnSubmit();

                }
            }


            if (rbSectionTwentyFour.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "24");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("24", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSectionTwentyFour.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSectionTwentyFour.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "24");
                if (rbnonVAProvider.SelectedValue == "1")
                {
                    List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("24", survey.SURVEYS_ID);

                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }
                }

            }

            if (rbSectionTwentyFive.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "25");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("25", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSectionTwentyFive.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSectionTwentyFive.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "25");
                if (rbnonVAProvider.SelectedValue == "1")
                {
                    List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("25", survey.SURVEYS_ID);

                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }
                }
            }

            if (rbSectionTwentySix.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "26");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("26", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSectionTwentySix.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSectionTwentySix.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "26");
                if (rbnonVAProvider.SelectedValue == "1")
                {
                    List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("26", survey.SURVEYS_ID);

                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }
                }
            }

            if (rbSectionTwentySeven.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "27");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("27", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSectionTwentySeven.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSectionTwentySeven.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "27");
                if (rbnonVAProvider.SelectedValue == "1")
                {
                    List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("27", survey.SURVEYS_ID);

                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }
                }

            }

            if (rbSectionTwentyEight.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "28");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("28", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSectionTwentyEight.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSectionTwentyEight.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "28");
                if (rbnonVAProvider.SelectedValue == "1")
                {
                    List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("28", survey.SURVEYS_ID);

                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }
                }
            }

            if (!String.IsNullOrEmpty(OtherConditionsTextBox.Text.Trim()))
            {

                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "28-A");
                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("28-A", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == 1).STD_QUESTION_CHOICE_ID;
                    result.RESULT_TEXT = OtherConditionsTextBox.Text.Trim();

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == 1).STD_QUESTION_CHOICE_ID;
                    result.RESULT_TEXT = OtherConditionsTextBox.Text.Trim();

                    survey.SURVEY_RESULTs.Add(result);

                }

            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "28-A");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("28-A", survey.SURVEYS_ID);

                if (rbnonVAProvider.SelectedValue == "1" || rbSectionTwentyEight.SelectedValue != "5")
                {

                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        result.RESULT_TEXT = null;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);
                    }

                }
                else
                {                    //textbox was emptied manually so just delete result
                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.SetAsDeleteOnSubmit();

                    }
                }
            }

            if (rbSectionTwentyNine.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "29");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("29", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSectionTwentyNine.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSectionTwentyNine.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "29");
                if (rbnonVAProvider.SelectedValue == "1")
                {
                    List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("29", survey.SURVEYS_ID);

                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }
                }
            }

            if (rbSectionTwentyNineA.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "29-A");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("29-A", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSectionTwentyNineA.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSectionTwentyNineA.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "29-A");
                if (rbnonVAProvider.SelectedValue == "1" || rbSectionTwentyNine.SelectedValue == "2"
                        || rbSectionTwentyNine.SelectedValue == "4" || rbSectionTwentyNine.SelectedValue == "5")
                {
                    List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("29-A", survey.SURVEYS_ID);

                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }
                }
            }

            STD_QUESTION questionConsult = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "29-B");
            List<SURVEY_RESULT> resultsConsult = _tbiInstrumentManager.GetChoicesByQuestionNumber("29-B", survey.SURVEYS_ID);
            selectedItems = 0;
            foreach (ListItem item in ConsultRequestListBox.Items)
            {
                //result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE != null && c.STD_QUESTION_CHOICE.STD_QUESTION != null && c.STD_QUESTION_CHOICE.STD_QUESTION.QUESTION_NUMBER == "5-D-5" && c.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER == int.Parse(item.Value)).FirstOrDefault();
                //result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.).FirstOrDefault();                              

                var selection = resultsConsult.Where(c => c.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER == int.Parse(item.Value)).FirstOrDefault();


                if (item.Selected)
                {
                    selectedItems++;
                    if (selection != null)
                    {
                        //found it so it was here and no need to add it


                    }
                    else
                    {
                        //have not found it so need to add it.
                        result = new SURVEY_RESULT();

                        result.STD_QUESTION_CHOICE_ID = questionConsult.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == int.Parse(item.Value)).STD_QUESTION_CHOICE_ID;

                        survey.SURVEY_RESULTs.Add(result);
                    }
                }
                else
                {
                    if (selection != null)
                    {
                        //found it so need to remove it 
                        result = survey.SURVEY_RESULTs.FirstOrDefault(c => c.STD_QUESTION_CHOICE_ID == selection.STD_QUESTION_CHOICE_ID);
                        //result.SetAsDeleteOnSubmit();
                        result.SetAsDeleteOnSubmit();
                    }
                    else
                    {
                        //it wasn't there so no need to do anything

                    }
                }
            }
            //}
            if (selectedItems == 0)
            {
                if (rbnonVAProvider.SelectedValue == "1" || rbSectionTwentyNine.SelectedValue == "2"
                        || rbSectionTwentyNine.SelectedValue == "4" || rbSectionTwentyNine.SelectedValue == "5")
                {

                    STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "29-B");

                    SURVEY_RESULT res = resultsConsult.Where(c => c.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER == null).FirstOrDefault();

                    if (res == null)
                    {
                        result = new SURVEY_RESULT();

                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                        survey.SURVEY_RESULTs.Add(result);
                    }
                }
            }
            else
            {
                SURVEY_RESULT res = resultsConsult.Where(c => c.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER == null).FirstOrDefault();

                if (res != null)
                {
                    result = survey.SURVEY_RESULTs.FirstOrDefault(c => c.STD_QUESTION_CHOICE_ID == res.STD_QUESTION_CHOICE_ID);

                    result.SetAsDeleteOnSubmit();

                }
            }

            if (!String.IsNullOrEmpty(OtherConsultsTextBox.Text.Trim()))
            {

                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "29-B-1");
                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("29-B-1", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == 1).STD_QUESTION_CHOICE_ID;
                    result.RESULT_TEXT = OtherConsultsTextBox.Text.Trim();

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == 1).STD_QUESTION_CHOICE_ID;
                    result.RESULT_TEXT = OtherConsultsTextBox.Text.Trim();

                    survey.SURVEY_RESULTs.Add(result);

                }

            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "29-B-1");
                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("29-B-1", survey.SURVEYS_ID);

                if (rbnonVAProvider.SelectedValue == "1" || rbSectionTwentyNine.SelectedValue == "2"
                        || rbSectionTwentyNine.SelectedValue == "4" || rbSectionTwentyNine.SelectedValue == "5"
                    || !ConsultRequestListBox.Items.FindByValue("14").Selected)
                {

                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        result.RESULT_TEXT = null;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);
                    }

                }
                else
                {                    //textbox was emptied manually so just delete result
                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.SetAsDeleteOnSubmit();

                    }
                }
            }

            STD_QUESTION questionPoly = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "29-C");
            List<SURVEY_RESULT> resultsPoly = _tbiInstrumentManager.GetChoicesByQuestionNumber("29-C", survey.SURVEYS_ID);
            selectedItems = 0;
            foreach (ListItem item in PNSListBox.Items)
            {
                //result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE != null && c.STD_QUESTION_CHOICE.STD_QUESTION != null && c.STD_QUESTION_CHOICE.STD_QUESTION.QUESTION_NUMBER == "5-D-5" && c.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER == int.Parse(item.Value)).FirstOrDefault();
                //result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.).FirstOrDefault();                              

                var selection = resultsPoly.Where(c => c.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER == int.Parse(item.Value)).FirstOrDefault();


                if (item.Selected)
                {
                    selectedItems++;
                    if (selection != null)
                    {
                        //found it so it was here and no need to add it


                    }
                    else
                    {
                        //have not found it so need to add it.
                        result = new SURVEY_RESULT();

                        result.STD_QUESTION_CHOICE_ID = questionPoly.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == int.Parse(item.Value)).STD_QUESTION_CHOICE_ID;

                        survey.SURVEY_RESULTs.Add(result);
                    }
                }
                else
                {
                    if (selection != null)
                    {
                        //found it so need to remove it 
                        result = survey.SURVEY_RESULTs.FirstOrDefault(c => c.STD_QUESTION_CHOICE_ID == selection.STD_QUESTION_CHOICE_ID);
                        //result.SetAsDeleteOnSubmit();
                        result.SetAsDeleteOnSubmit();
                    }
                    else
                    {
                        //it wasn't there so no need to do anything

                    }
                }
            }
            //}
            if (selectedItems == 0)
            {

                if (rbnonVAProvider.SelectedValue == "1" || rbSectionTwentyNine.SelectedValue == "2"
                        || rbSectionTwentyNine.SelectedValue == "4" || rbSectionTwentyNine.SelectedValue == "5")
                {
                    STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "29-C");

                    SURVEY_RESULT res = resultsPoly.Where(c => c.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER == null).FirstOrDefault();

                    if (res == null)
                    {

                        result = new SURVEY_RESULT();

                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                        survey.SURVEY_RESULTs.Add(result);
                    }
                }
            }
            else
            {
                SURVEY_RESULT res = resultsPoly.Where(c => c.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER == null).FirstOrDefault();

                if (res != null)
                {
                    result = survey.SURVEY_RESULTs.FirstOrDefault(c => c.STD_QUESTION_CHOICE_ID == res.STD_QUESTION_CHOICE_ID);

                    result.SetAsDeleteOnSubmit();

                }
            }


            if (rbSectionTwentyNineD.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "29-D");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("29-D", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSectionTwentyNineD.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSectionTwentyNineD.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "29-D");
                if (rbnonVAProvider.SelectedValue == "1" || rbSectionTwentyNine.SelectedValue == "2"
                        || rbSectionTwentyNine.SelectedValue == "4" || rbSectionTwentyNine.SelectedValue == "5")
                {
                    List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("29-D", survey.SURVEYS_ID);

                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }
                }
            }

            if (rbSectionTwentyNineDOne.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "29-D-1");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("29-D-1", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSectionTwentyNineDOne.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSectionTwentyNineDOne.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "29-D-1");
                if (rbnonVAProvider.SelectedValue == "1" || rbSectionTwentyNine.SelectedValue == "2"
                        || rbSectionTwentyNine.SelectedValue == "4" || rbSectionTwentyNine.SelectedValue == "5")
                {
                    List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("29-D-1", survey.SURVEYS_ID);

                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }
                }
            }

            if (rbSectionTwentyNineE.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "29-E");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("29-E", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSectionTwentyNineE.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSectionTwentyNineE.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "29-E");
                if (rbnonVAProvider.SelectedValue == "1" || rbSectionTwentyNine.SelectedValue == "2"
                        || rbSectionTwentyNine.SelectedValue == "4" || rbSectionTwentyNine.SelectedValue == "5")
                {
                    List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("29-E", survey.SURVEYS_ID);

                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }
                }
            }

            if (rbSectionTwentyNineF.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "29-F");
                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("29-F", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSectionTwentyNineF.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSectionTwentyNineF.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {

                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "29-F");
                if (rbnonVAProvider.SelectedValue == "1" || rbSectionTwentyNine.SelectedValue == "2"
                        || rbSectionTwentyNine.SelectedValue == "4" || rbSectionTwentyNine.SelectedValue == "5")
                {
                    List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("29-F", survey.SURVEYS_ID);

                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }
                }
            }

            if (rbSectionTwentyNineG.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "29-G");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("29-G", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSectionTwentyNineG.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSectionTwentyNineG.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "29-G");
                if (rbnonVAProvider.SelectedValue == "1" || rbSectionTwentyNine.SelectedValue == "2"
                        || rbSectionTwentyNine.SelectedValue == "4" || rbSectionTwentyNine.SelectedValue == "5")
                {
                    List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("29-G", survey.SURVEYS_ID);

                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }
                }
            }

            if (rbSectionTwentyNineH.SelectedIndex > -1)
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "29-H");

                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("29-H", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSectionTwentyNineH.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == rbSectionTwentyNineH.SelectedIndex + 1).STD_QUESTION_CHOICE_ID;

                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {

                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "29-H");
                if (rbnonVAProvider.SelectedValue == "1" || rbSectionTwentyNine.SelectedValue == "2"
                        || rbSectionTwentyNine.SelectedValue == "4" || rbSectionTwentyNine.SelectedValue == "5")
                {
                    List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("29-H", survey.SURVEYS_ID);

                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);

                    }
                }

            }

            //question 29-I - other medications
            STD_QUESTION medsConsult = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "29-I");
            List<SURVEY_RESULT> medResultsConsult = _tbiInstrumentManager.GetChoicesByQuestionNumber("29-I", survey.SURVEYS_ID);
            selectedItems = 0;
            foreach (ListItem item in MedicationChangeListBox.Items)
            {
                //result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE != null && c.STD_QUESTION_CHOICE.STD_QUESTION != null && c.STD_QUESTION_CHOICE.STD_QUESTION.QUESTION_NUMBER == "5-D-5" && c.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER == int.Parse(item.Value)).FirstOrDefault();
                //result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.).FirstOrDefault();                              

                var selection = medResultsConsult.Where(c => c.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER == int.Parse(item.Value)).FirstOrDefault();


                if (item.Selected)
                {
                    selectedItems++;
                    if (selection != null)
                    {
                        //found it so it was here and no need to add it


                    }
                    else
                    {
                        //have not found it so need to add it.
                        result = new SURVEY_RESULT();

                        result.STD_QUESTION_CHOICE_ID = medsConsult.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == int.Parse(item.Value)).STD_QUESTION_CHOICE_ID;

                        survey.SURVEY_RESULTs.Add(result);
                    }
                }
                else
                {
                    if (selection != null)
                    {
                        //found it so need to remove it 
                        result = survey.SURVEY_RESULTs.FirstOrDefault(c => c.STD_QUESTION_CHOICE_ID == selection.STD_QUESTION_CHOICE_ID);
                        //result.SetAsDeleteOnSubmit();
                        result.SetAsDeleteOnSubmit();
                    }
                    else
                    {
                        //it wasn't there so no n eed to do anything

                    }
                }
            }
            //}
            if (selectedItems == 0)
            {
                if (rbnonVAProvider.SelectedValue == "1" || rbSectionTwentyNine.SelectedValue == "2"
                        || rbSectionTwentyNine.SelectedValue == "4" || rbSectionTwentyNine.SelectedValue == "5")
                {

                    STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "29-I");

                    SURVEY_RESULT res = medResultsConsult.Where(c => c.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER == null).FirstOrDefault();

                    if (res == null)
                    {
                        result = new SURVEY_RESULT();

                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;

                        survey.SURVEY_RESULTs.Add(result);
                    }
                }
            }
            else
            {
                SURVEY_RESULT res = medResultsConsult.Where(c => c.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER == null).FirstOrDefault();

                if (res != null)
                {
                    result = survey.SURVEY_RESULTs.FirstOrDefault(c => c.STD_QUESTION_CHOICE_ID == res.STD_QUESTION_CHOICE_ID);

                    result.SetAsDeleteOnSubmit();

                }
            }

            if (!String.IsNullOrEmpty(OtherSymptomsTextBox.Text.Trim()))
            {

                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "29-I-1");
                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("29-I-1", survey.SURVEYS_ID);

                if (results.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == 1).STD_QUESTION_CHOICE_ID;
                    result.RESULT_TEXT = OtherSymptomsTextBox.Text.Trim();

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == 1).STD_QUESTION_CHOICE_ID;
                    result.RESULT_TEXT = OtherSymptomsTextBox.Text.Trim();

                    survey.SURVEY_RESULTs.Add(result);

                }

            }
            else
            {
                STD_QUESTION question = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "29-I-1");
                List<SURVEY_RESULT> results = _tbiInstrumentManager.GetChoicesByQuestionNumber("29-I-1", survey.SURVEYS_ID);

                if (rbnonVAProvider.SelectedValue == "1" || rbSectionTwentyNine.SelectedValue == "2"
                        || rbSectionTwentyNine.SelectedValue == "4" || rbSectionTwentyNine.SelectedValue == "5"
                    || !MedicationChangeListBox.Items.FindByValue("9").Selected)
                //|| rbSectionTwentyNineI.SelectedValue != "9"  )
                {

                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        result.RESULT_TEXT = null;

                    }
                    else
                    {
                        result = new SURVEY_RESULT();
                        result.STD_QUESTION_CHOICE_ID = question.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                        survey.SURVEY_RESULTs.Add(result);
                    }

                }
                else
                {                    //textbox was emptied manually so just delete result
                    if (results.Count() > 0)
                    {
                        result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                        result.SetAsDeleteOnSubmit();

                    }
                }
            }

            STD_QUESTION question30 = questions.FirstOrDefault(s => s.QUESTION_NUMBER == "30");

            List<SURVEY_RESULT> results30 = _tbiInstrumentManager.GetChoicesByQuestionNumber("30", survey.SURVEYS_ID);

            if (rbSectionTwentyNine.SelectedValue == "2"
                        || rbSectionTwentyNine.SelectedValue == "4" || rbSectionTwentyNine.SelectedValue == "5")
            {

                if (results30.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results30.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();
                    result.STD_QUESTION_CHOICE_ID = question30.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                    result.RESULT_TEXT = PlanDetailsTextBox.Text.Trim();

                }
                else
                {
                    result = new SURVEY_RESULT();
                    result.STD_QUESTION_CHOICE_ID = question30.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == null).STD_QUESTION_CHOICE_ID;
                    survey.SURVEY_RESULTs.Add(result);
                }

            }
            else
            {
                if (results30.Count() > 0)
                {
                    result = survey.SURVEY_RESULTs.Where(c => c.STD_QUESTION_CHOICE_ID == results30.First().STD_QUESTION_CHOICE_ID).FirstOrDefault();

                    result.STD_QUESTION_CHOICE_ID = question30.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == 1).STD_QUESTION_CHOICE_ID;
                    result.RESULT_TEXT = PlanDetailsTextBox.Text.Trim();

                }
                else
                {
                    result = new SURVEY_RESULT();

                    result.STD_QUESTION_CHOICE_ID = question30.STD_QUESTION_CHOICEs.FirstOrDefault(a => a.CHOICE_SORT_ORDER == 1).STD_QUESTION_CHOICE_ID;
                    result.RESULT_TEXT = PlanDetailsTextBox.Text.Trim();

                    survey.SURVEY_RESULTs.Add(result);
                }
            }
        }
        catch (Exception ex)
        {
            Exception _tbilogerror = HandleTBIException(ex, "InstrumentEvaluationEntry.aspx", "100029", "SaveSurvey()");
        }
    }

    private void SetUpEvalSurvey(SURVEY survey)
    {
        string _question = "";
        try
        {

            foreach (var result in survey.SURVEY_RESULTs)
            {
                switch (result.STD_QUESTION_CHOICE.STD_QUESTION.QUESTION_NUMBER)
                {
                    case "A":
                        _question = "A";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbnonVAProvider.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbnonVAProvider.SelectedIndex = -1;


                        }
                        break;

                    case "1":
                        _question = "1";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbMaritalStatus.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbMaritalStatus.SelectedIndex = -1;

                        }

                        break;

                    case "2":
                        _question = "2";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbEducationalLevel.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbEducationalLevel.SelectedIndex = -1;

                        }

                        break;

                    case "3":
                        _question = "3";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbEmploymentStatus.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbEmploymentStatus.SelectedIndex = -1;

                        }

                        break;

                    case "4":
                        _question = "4";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbInjuriesQuantity.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbInjuriesQuantity.SelectedIndex = -1;

                        }

                        break;
                    case "4-A-1":
                        _question = "4-A-1";
                        InjuryMonthTextBox.Text = result.RESULT_TEXT;
                        break;

                    case "4-A-2":
                        _question = "4-A-2";
                        InjuryYearTextBox.Text = result.RESULT_TEXT;
                        break;

                    case "4-B-1":
                        _question = "4-B-1";
                        SecondInjuryMonthTextBox.Text = result.RESULT_TEXT;
                        break;

                    case "4-B-2":
                        _question = "4-B-2";
                        SecondInjuryYearTextBox.Text = result.RESULT_TEXT;
                        break;

                    case "4-C-1":
                        _question = "4-C-1";
                        LeastInjuryMonthTextBox.Text = result.RESULT_TEXT;
                        break;

                    case "4-C-2":
                        _question = "4-C-2";
                        LeastInjuryYearTextBox.Text = result.RESULT_TEXT;
                        break;

                    case "5-A":
                        _question = "5-A";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbFiveASubsection.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbFiveASubsection.SelectedIndex = -1;

                        }
                        break;
                    case "5-B":
                        _question = "5-B";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbFiveBSubsection.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbFiveBSubsection.SelectedIndex = -1;

                        }
                        break;

                    case "5-C":
                        _question = "5-C";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbFiveCSubsection.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbFiveCSubsection.SelectedIndex = -1;

                        }
                        break;

                    case "5-D":
                        _question = "5-D";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbFiveDSubsection.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbFiveDSubsection.SelectedIndex = -1;

                        }
                        break;

                    case "5-D-1":
                        _question = "5-D-1";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbFiveDOneSubsection.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbFiveDOneSubsection.SelectedIndex = -1;

                        }
                        break;

                    case "5-D-1-a":
                        _question = "5-D-1-a";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbFiveDOneASection.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbFiveDOneASection.SelectedIndex = -1;

                        }
                        break;

                    case "5-D-2":
                        _question = "5-D-2";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbFiveDTwoSection.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbFiveDTwoSection.SelectedIndex = -1;

                        }
                        break;

                    case "5-D-3":
                        _question = "5-D-3";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbFiveDThreeSection.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbFiveDThreeSection.SelectedIndex = -1;

                        }
                        break;

                    case "5-D-4":
                        _question = "5-D-4";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbFiveDFourSection.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbFiveDFourSection.SelectedIndex = -1;

                        }
                        break;

                    case "5-D-5":
                        //checkbox based
                        _question = "5-D-5";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {

                            ListItem item = BlastExplosureTypeList.Items.FindByValue(result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value.ToString());
                            item.Selected = true;

                        }
                        else
                        {
                            //none selected so nothing to do 

                        }
                        break;


                    case "5-E":
                        _question = "5-E";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbFiveESection.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbFiveESection.SelectedIndex = -1;

                        }
                        break;

                    case "6":
                        _question = "6";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbSixSection.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbSixSection.SelectedIndex = -1;

                        }
                        break;


                    case "6-A":
                        _question = "6-A";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbSixASection.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbSixASection.SelectedIndex = -1;

                        }
                        break;

                    case "7":
                        _question = "7";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbSevenSection.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbSevenSection.SelectedIndex = -1;

                        }
                        break;

                    case "7-A":
                        _question = "7-A";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbSevenASection.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbSevenASection.SelectedIndex = -1;

                        }
                        break;

                    case "8":
                        _question = "8";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbEightSection.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbEightSection.SelectedIndex = -1;

                        }
                        break;

                    case "8-A":
                        _question = "8-A";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbEightASection.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbEightASection.SelectedIndex = -1;

                        }
                        break;

                    case "9":
                        _question = "9";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbNineSection.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbNineSection.SelectedIndex = -1;

                        }
                        break;

                    case "10":
                        _question = "10";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbTenSection.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbTenSection.SelectedIndex = -1;

                        }
                        break;

                    case "11":
                        _question = "11";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbElevenSection.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbElevenSection.SelectedIndex = -1;

                        }
                        break;

                    case "12":
                        _question = "12";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbTwelveSection.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbTwelveSection.SelectedIndex = -1;

                        }
                        break;

                    case "12-A":
                        _question = "12-A";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbTwelveASection.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbTwelveASection.SelectedIndex = -1;

                        }
                        break;

                    case "13":
                        _question = "13";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbThirteenSection.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbThirteenSection.SelectedIndex = -1;

                        }
                        break;

                    case "14":
                        _question = "14";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbFourteenSection.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbFourteenSection.SelectedIndex = -1;

                        }
                        break;

                    case "15":
                        _question = "15";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbFifteenSection.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbFifteenSection.SelectedIndex = -1;

                        }
                        break;

                    case "16-A":
                        _question = "16-A";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbSixteenASection.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbSixteenASection.SelectedIndex = -1;

                        }
                        break;

                    case "16-B":
                        _question = "16-B";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbSixteenBSection.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbSixteenBSection.SelectedIndex = -1;

                        }
                        break;

                    case "16-C":
                        _question = "16-C";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbSixteenCSection.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbSixteenCSection.SelectedIndex = -1;

                        }
                        break;

                    case "16-D":
                        _question = "16-D";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbSixteenDSection.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbSixteenDSection.SelectedIndex = -1;

                        }
                        break;

                    case "16-E":
                        _question = "16-E";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbSixteenESection.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbSixteenESection.SelectedIndex = -1;

                        }
                        break;

                    case "16-F":
                        _question = "16-F";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbSixteenFSection.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbSixteenFSection.SelectedIndex = -1;

                        }
                        break;

                    case "16-G":
                        _question = "16-G";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbSixteenGSection.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbSixteenGSection.SelectedIndex = -1;

                        }
                        break;

                    case "16-H":
                        _question = "16-H";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbSixteenHSection.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbSixteenHSection.SelectedIndex = -1;

                        }
                        break;

                    case "16-I":
                        _question = "16-I";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbSixteenISection.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbSixteenISection.SelectedIndex = -1;

                        }
                        break;

                    case "16-J":
                        _question = "16-J";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbSixteenJSection.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbSixteenJSection.SelectedIndex = -1;

                        }
                        break;

                    case "16-K":
                        _question = "16-K";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbSixteenKSection.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbSixteenKSection.SelectedIndex = -1;

                        }
                        break;

                    case "16-L":
                        _question = "16-L";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbSixteenLSection.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbSixteenLSection.SelectedIndex = -1;

                        }
                        break;

                    case "16-M":
                        _question = "16-M";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbSixteenMSection.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbSixteenMSection.SelectedIndex = -1;

                        }
                        break;

                    case "16-N":
                        _question = "16-N";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbSixteenNSection.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbSixteenNSection.SelectedIndex = -1;

                        }
                        break;

                    case "16-O":
                        _question = "16-O";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbSixteenOSection.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbSixteenOSection.SelectedIndex = -1;

                        }
                        break;

                    case "16-P":
                        _question = "16-P";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbSixteenPSection.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbSixteenPSection.SelectedIndex = -1;

                        }
                        break;

                    case "16-Q":
                        _question = "16-Q";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbSixteenQSection.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbSixteenQSection.SelectedIndex = -1;

                        }
                        break;

                    case "16-R":
                        _question = "16-R";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbSixteenRSection.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbSixteenRSection.SelectedIndex = -1;

                        }
                        break;

                    case "16-S":
                        _question = "16-S";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbSixteenSSection.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbSixteenSSection.SelectedIndex = -1;

                        }
                        break;

                    case "16-T":
                        _question = "16-T";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbSixteenTSection.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbSixteenTSection.SelectedIndex = -1;

                        }
                        break;

                    case "16-U":
                        _question = "16-U";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbSixteenUSection.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbSixteenUSection.SelectedIndex = -1;

                        }
                        break;

                    case "16-V":
                        _question = "16-V";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbSixteenVSection.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbSixteenVSection.SelectedIndex = -1;

                        }
                        break;

                    case "17":
                        _question = "17";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbSeventeenSection.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbSeventeenSection.SelectedIndex = -1;

                        }
                        break;

                    case "17-A":
                        _question = "17-A";
                        LifeAreasDifficultiesTextBox.Text = result.RESULT_TEXT;
                        break;

                    case "18":
                        _question = "18";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbEighteenSection.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbEighteenSection.SelectedIndex = -1;

                        }
                        break;

                    case "18-A":
                        _question = "18-A";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {

                            BodyPartsList.Items.FindByValue(result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value.ToString()).Selected = true;

                        }
                        else
                        {
                            //none selected so nothig to do 

                        }
                        break;

                    case "18-B":
                        _question = "18-B";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbEighteenBSection.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbEighteenBSection.SelectedIndex = -1;

                        }
                        break;

                    case "18-C":
                        _question = "18-C";
                        LifeAreasPainTextBox.Text = result.RESULT_TEXT;
                        break;

                    case "19":
                        _question = "19";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbSectionNineteen.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbSectionNineteen.SelectedIndex = -1;

                        }
                        break;

                    case "20":
                        _question = "20";
                        AdditionalHistoryTextBox.Text = result.RESULT_TEXT;
                        break;

                    case "21":
                        _question = "21";
                        CurrentMedicationTextBox.Text = result.RESULT_TEXT;
                        break;

                    case "21-A":
                        _question = "21-A";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rblMedicationReconciliationPerformed.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rblMedicationReconciliationPerformed.SelectedIndex = -1;

                        }
                        break;

                    case "21-B":
                        _question = "21-B";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rblMedicationGiven.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rblMedicationGiven.SelectedIndex = -1;

                        }
                        break;

                    case "21-C":
                        _question = "21-C";
                        txtNoMedicationReconciliationPerformed.Text = result.RESULT_TEXT;
                        break;

                    case "22":
                        _question = "22";
                        PhysicalExaminationTextBox.Text = result.RESULT_TEXT;
                        break;

                    case "23":
                        _question = "23";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbSectionTwentyThree.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbSectionTwentyThree.SelectedIndex = -1;

                        }
                        break;

                    case "23-A":
                        _question = "23-A";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {

                            DisorderSymptomsList.Items.FindByValue(result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value.ToString()).Selected = true;

                        }
                        else
                        {
                            //none selected so nothig to do 

                        }
                        break;

                    case "24":
                        _question = "24";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbSectionTwentyFour.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbSectionTwentyFour.SelectedIndex = -1;

                        }
                        break;

                    case "25":
                        _question = "25";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbSectionTwentyFive.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbSectionTwentyFive.SelectedIndex = -1;

                        }
                        break;

                    case "26":
                        _question = "26";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbSectionTwentySix.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbSectionTwentySix.SelectedIndex = -1;

                        }
                        break;

                    case "27":
                        _question = "27";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbSectionTwentySeven.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbSectionTwentySeven.SelectedIndex = -1;

                        }
                        break;

                    case "28":
                        _question = "28";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbSectionTwentyEight.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbSectionTwentyEight.SelectedIndex = -1;

                        }
                        break;

                    case "28-A":
                        _question = "28-A";
                        OtherConditionsTextBox.Text = result.RESULT_TEXT;
                        break;

                    case "29":
                        _question = "29";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbSectionTwentyNine.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbSectionTwentyNine.SelectedIndex = -1;

                        }
                        break;

                    case "29-A":
                        _question = "29-A";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbSectionTwentyNineA.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbSectionTwentyNineA.SelectedIndex = -1;

                        }
                        break;

                    case "29-B":
                        _question = "29-B";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {

                            ConsultRequestListBox.Items.FindByValue(result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value.ToString()).Selected = true;

                        }
                        else
                        {
                            //none selected so nothig to do 

                        }
                        break;

                    case "29-B-1":
                        _question = "29-B-1";
                        OtherConsultsTextBox.Text = result.RESULT_TEXT;
                        break;

                    case "29-C":
                        _question = "29-C";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {

                            PNSListBox.Items.FindByValue(result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value.ToString()).Selected = true;


                        }
                        else
                        {
                            //none selected so nothig to do 

                        }
                        break;

                    case "29-D":
                        _question = "29-D";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbSectionTwentyNineD.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbSectionTwentyNineD.SelectedIndex = -1;

                        }
                        break;

                    case "29-D-1":
                        _question = "29-D-1";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbSectionTwentyNineDOne.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbSectionTwentyNineDOne.SelectedIndex = -1;

                        }
                        break;

                    case "29-E":
                        _question = "29-E";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbSectionTwentyNineE.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbSectionTwentyNineE.SelectedIndex = -1;

                        }
                        break;

                    case "29-F":
                        _question = "29-F";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbSectionTwentyNineF.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbSectionTwentyNineF.SelectedIndex = -1;

                        }
                        break;

                    case "29-G":
                        _question = "29-G";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbSectionTwentyNineG.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbSectionTwentyNineG.SelectedIndex = -1;

                        }
                        break;

                    case "29-H":
                        _question = "29-H";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            rbSectionTwentyNineH.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                        }
                        else
                        {
                            rbSectionTwentyNineH.SelectedIndex = -1;

                        }
                        break;
                    case "29-I":
                        _question = "29-I";
                        if (result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.HasValue)
                        {
                            //rbSectionTwentyNineI.SelectedIndex = result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value - 1;
                            MedicationChangeListBox.Items.FindByValue(result.STD_QUESTION_CHOICE.CHOICE_SORT_ORDER.Value.ToString()).Selected = true;

                        }
                        else
                        {
                            //rbSectionTwentyNineI.SelectedIndex = -1;

                        }
                        break;

                    case "29-I-1":
                        _question = "29-I-1";
                        OtherSymptomsTextBox.Text = result.RESULT_TEXT;
                        break;

                    case "30":
                        _question = "30";
                        PlanDetailsTextBox.Text = result.RESULT_TEXT;
                        break;

                    default:
                        break;



                }

            }
        }
        catch (Exception ex)
        {
            string _functionquestion = "SetUpEvalSurvey()" + _question;
            Exception _tbilogerror = HandleTBIException(ex, "InstrumentEvaluationEntry.aspx", "100029", _functionquestion);
        }
    }

    private List<STD_QUESTION> GetAllQuestionsForEvalSurvey()
    {
        int evalSurvey = 2;
        return _tbiInstrumentManager.SelectAllQuestions(evalSurvey).ToList();

    }

    private void SetDefaultValues()
    {
        rbnonVAProvider.SelectedIndex = 0; //Default to NO
        rbSectionTwentyNineD.SelectedIndex = 0; //Default to NO
        rbSectionTwentyNineDOne.SelectedIndex = 0; //Default to NO
        rbSectionTwentyNineE.SelectedIndex = 0; //Default to NO
        rbSectionTwentyNineF.SelectedIndex = 0; //Default to NO
        rbSectionTwentyNineG.SelectedIndex = 0; //Default to NO
        rbSectionTwentyNineH.SelectedIndex = 0; //Default to NO
    }

    #endregion
}
